use clap::Parser;
use std::path::PathBuf;
use log::{info, debug, error};

mod directory_processor;
mod tools;
mod error;
mod logging;
#[cfg(test)]
mod tests;

use directory_processor::DirectoryProcessor;
use logging::{LogConfig, init_logging};

pub const FILES_TO_COPY: [&str; 10] = [
    "jpg", "jpeg", "png", "gif", "bmp", "tiff", "webp", "avif", "txt", "md",
];
pub const FILES_TO_CONVERT: [&str; 3] = ["odt", "doc", "docx"];
pub const PATHS_TO_IGNORE: [&str; 5] = [".DS_Store", ".syncthing", ".sync-conflict-", ".stfolder", ".stversions"];

#[derive(Parser, Debug)]
#[command(
    author,
    version,
    about = "Convert source directory with document files (odt/doc/docx) to target path with pdf files with changes verification"
)]
struct Args {
    #[arg(help = "Source directory with .odt, .doc, or .docx files")]
    source: PathBuf,

    #[arg(help = "Target directory for PDFs converted files")]
    dest: PathBuf,

    #[arg(long, help = "Log file path (optional)")]
    log_file: Option<PathBuf>,

    #[arg(
        long,
        help = "Log level (error, warn, info, debug, trace)",
        default_value = "info"
    )]
    log_level: String,

    #[arg(
        long,
        help = "Append to log file instead of overwriting",
        default_value_t = false
    )]
    append_log: bool,
}

fn main() {
    let args = Args::parse();

    let log_config = LogConfig {
        log_file: args.log_file.to_owned(),
        log_level: args.log_level.to_owned(),
        append_log: args.append_log.to_owned(),
    };

    if let Err(e) = init_logging(&log_config) {
        eprintln!("Failed to initialize logging: {}", e);
        std::process::exit(1);
    }

    info!("Starting document conversion");
    debug!("Source directory: {}", args.source.display());
    debug!("Target directory: {}", args.dest.display());

    let mut processor = DirectoryProcessor::new(args.source, args.dest);
    if let Err(e) = processor.process() {
        error!("Error processing directory: {}", e);
        std::process::exit(1);
    }

    info!("Document conversion completed successfully");
}
